@@ -29,7 +29,7 @@ def delete_cloud_one_policies(CLOUD_ONE_API_KEY: str):
     parsed = message.text
     x = json.loads(parsed, object_hook=lambda d: SimpleNamespace(**d))
     policyNumbers = []
-    for key in x.policies:
+    for key in x.policies:  # ERRORS here
         policyNumbers.append(key.ID)
     if policyNumbers:
         for policyID in policyNumbers:
@@ -49,13 +49,13 @@ def ListAllPolicy(url_link_final, tenant1key):
     url = url_link_final + "api/policies"
     response = safe_request(tenant1key, "GET", url, payload=payload, cert=cert)
     describe = str(response.text)
-    oldpolicyname = []
+    oldpolicynameid_dict = {}
     oldpolicyid = []
     namejson = json.loads(describe)
     for policy in namejson["policies"]:
-        oldpolicyname.append(str(policy["name"]))
+        oldpolicynameid_dict[str(policy["name"])] = str(policy["ID"])
         oldpolicyid.append(str(policy["ID"]))
-    return oldpolicyid
+    return oldpolicyid, oldpolicynameid_dict
 
 
 def GetPolicy(policyIDs, url_link_final, tenant1key):
